AdsManager class
Constructors
- AdsManager()
-
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
fetchAdsFromAPI(
) → Future< void> - ✅ Fetch Ads from the API
-
getNextAdUnit(
String adType) → String? - ✅ Get next available Ad Unit ID for a specific ad type (rotation logic)
-
initializeAds(
) → Future< void> - ✅ Initialize Mobile Ads and fetch ads from API
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited