Ads class
Constructors
- Ads({required String id, required int adId, required String type, required String typeName, required String typeSize, required String clientRedirectUrl, required String adsName, required String cdnLink, required String adsPosition, required String adsType, required String adUnitId, required int adsStatus, required int adsRotation, required String country, required int rotationOrder, required int company, required int contentType, required int impressionCount, String? lastImpressionAt})
-
Ads.fromJson(Map<
String, dynamic> json) -
factory
Properties
- adId → int
-
final
- adsName → String
-
final
- adsPosition → String
-
final
- adsRotation → int
-
final
- adsStatus → int
-
final
- adsType → String
-
final
- adUnitId → String
-
final
- cdnLink → String
-
final
- clientRedirectUrl → String
-
final
- company → int
-
final
- contentType → int
-
final
- country → String
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → String
-
final
- impressionCount → int
-
final
- lastImpressionAt → String?
-
final
- rotationOrder → int
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- type → String
-
final
- typeName → String
-
final
- typeSize → String
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited